/* autogenerated - do not edit */
#include <jim.h>
int Jim_initjimshInit(Jim_Interp *interp)
{
	if (Jim_PackageProvide(interp, "initjimsh", "1.0", JIM_ERRMSG)) return JIM_ERR;
	return Jim_EvalSource(interp, "initjimsh.tcl", 1, "\n"
"\n"
"\n"
"proc _jimsh_init {} {\n"
"	rename _jimsh_init {}\n"
"	global jim::exe jim::argv0 tcl_interactive auto_path tcl_platform\n"
"\n"
"\n"
"	if {[exists jim::argv0]} {\n"
"		if {[string match \"*/*\" $jim::argv0]} {\n"
"			set jim::exe [file join [pwd] $jim::argv0]\n"
"		} else {\n"
"			foreach path [split [env PATH \"\"] $tcl_platform(pathSeparator)] {\n"
"				set exec [file join [pwd] [string map {\\\\ /} $path] $jim::argv0]\n"
"				if {[file executable $exec]} {\n"
"					set jim::exe $exec\n"
"					break\n"
"				}\n"
"			}\n"
"		}\n"
"	}\n"
"\n"
"\n"
"	lappend p {*}[split [env JIMLIB {}] $tcl_platform(pathSeparator)]\n"
"	if {[exists jim::exe]} {\n"
"		lappend p [file dirname $jim::exe]\n"
"	}\n"
"	lappend p {*}$auto_path\n"
"	set auto_path $p\n"
"\n"
"	if {$tcl_interactive && [env HOME {}] ne \"\"} {\n"
"		foreach src {.jimrc jimrc.tcl} {\n"
"			if {[file exists [env HOME]/$src]} {\n"
"				uplevel #0 source [env HOME]/$src\n"
"				break\n"
"			}\n"
"		}\n"
"	}\n"
"	return \"\"\n"
"}\n"
"\n"
"if {$tcl_platform(platform) eq \"windows\"} {\n"
"	set jim::argv0 [string map {\\\\ /} $jim::argv0]\n"
"}\n"
"\n"
"\n"
"set tcl::autocomplete_commands {array clock debug dict file history info namespace package signal socket string tcl::prefix zlib}\n"
"\n"
"\n"
"\n"
"proc tcl::autocomplete {prefix} {\n"
"	if {[set space [string first \" \" $prefix]] != -1} {\n"
"		set cmd [string range $prefix 0 $space-1]\n"
"		if {$cmd in $::tcl::autocomplete_commands || [info channel $cmd] ne \"\"} {\n"
"			set arg [string range $prefix $space+1 end]\n"
"\n"
"			return [lmap p [$cmd -commands] {\n"
"				if {![string match \"${arg}*\" $p]} continue\n"
"				function \"$cmd $p\"\n"
"			}]\n"
"		}\n"
"	}\n"
"\n"
"	if {[string match \"source *\" $prefix]} {\n"
"		set path [string range $prefix 7 end]\n"
"		return [lmap p [glob -nocomplain \"${path}*\"] {\n"
"			function \"source $p\"\n"
"		}]\n"
"	}\n"
"\n"
"	return [lmap p [lsort [info commands $prefix*]] {\n"
"		if {[string match \"* *\" $p]} {\n"
"			continue\n"
"		}\n"
"		function $p\n"
"	}]\n"
"}\n"
"\n"
"\n"
"set tcl::stdhint_commands {array clock debug dict file history info namespace package signal string zlib}\n"
"\n"
"set tcl::stdhint_cols {\n"
"	none {0}\n"
"	black {30}\n"
"	red {31}\n"
"	green {32}\n"
"	yellow {33}\n"
"	blue {34}\n"
"	purple {35}\n"
"	cyan {36}\n"
"	normal {37}\n"
"	grey {30 1}\n"
"	gray {30 1}\n"
"	lred {31 1}\n"
"	lgreen {32 1}\n"
"	lyellow {33 1}\n"
"	lblue {34 1}\n"
"	lpurple {35 1}\n"
"	lcyan {36 1}\n"
"	white {37 1}\n"
"}\n"
"\n"
"\n"
"set tcl::stdhint_col $tcl::stdhint_cols(lcyan)\n"
"\n"
"\n"
"proc tcl::stdhint {string} {\n"
"	set result \"\"\n"
"	if {[llength $string] >= 2} {\n"
"		lassign $string cmd arg\n"
"		if {$cmd in $::tcl::stdhint_commands || [info channel $cmd] ne \"\"} {\n"
"			catch {\n"
"				set help [$cmd -help $arg]\n"
"				if {[string match \"Usage: $cmd *\" $help]} {\n"
"					set n [llength $string]\n"
"					set subcmd [lindex $help $n]\n"
"					incr n\n"
"					set hint [join [lrange $help $n end]]\n"
"					set prefix \"\"\n"
"					if {![string match \"* \" $string]} {\n"
"						if {$n == 3 && $subcmd ne $arg} {\n"
"\n"
"							set prefix \"[string range $subcmd [string length $arg] end] \"\n"
"						} else {\n"
"							set prefix \" \"\n"
"						}\n"
"					}\n"
"					set result [list $prefix$hint {*}$::tcl::stdhint_col]\n"
"				}\n"
"			}\n"
"		}\n"
"	}\n"
"	return $result\n"
"}\n"
"\n"
"_jimsh_init\n");
}
